﻿using System;
using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;
using UnityEngine.Events;

namespace TCSWindows
{
    public class MessaageBox : MonoBehaviour
    {
        public Text headerText;

        public Text messageText;

        public Button button1;
        public Text buttonText1;

        public Button button2;
        public Text buttonText2;

        public Button button3;
        public Text buttonText3;

        public MessageTemplate messageInfo;

        public MessageBoxEvent eventCallback;

        void Start()
        {
            button1.onClick.AddListener(() =>
            {
                eventCallback.Invoke(1);
                WindowManager.instance.PlayButtonSound();
                Close();
            });
            button2.onClick.AddListener(() =>
            {
                eventCallback.Invoke(2);
                WindowManager.instance.PlayButtonSound();
                Close();
            });
            button3.onClick.AddListener(() =>
            {
                eventCallback.Invoke(3);
                WindowManager.instance.PlayButtonSound();
                Close();
            });
        }

        void OnEnable()
        {
            if (messageInfo != null)
            {
                SetUpButtons();
                SetupText();
                transform.SetAsLastSibling();
            }
        }

        void SetUpButtons()
        {
            switch (messageInfo.numberOfButtons)
            {
                case 1:
                default:
                    button1.gameObject.SetActive(true);
                    button2.gameObject.SetActive(false);
                    button3.gameObject.SetActive(false);
                    break;
                case 2:
                    button1.gameObject.SetActive(true);
                    button2.gameObject.SetActive(true);
                    button3.gameObject.SetActive(false);
                    break;
                case 3:
                    button1.gameObject.SetActive(true);
                    button2.gameObject.SetActive(true);
                    button3.gameObject.SetActive(true);
                    break;
            }
        }

        void SetupText()
        {
            headerText.text = messageInfo.header;
            messageText.text = messageInfo.message;
            buttonText1.text = messageInfo.button1Text;
            buttonText2.text = messageInfo.button2Text;
            buttonText3.text = messageInfo.button3Text;

        }
        public void Close()
        {
            eventCallback.RemoveAllListeners();
            WindowManager.instance.CloseMessageBox();
        }
    }
    public class MessageTemplate
    {
        public string header;
        public string message;
        public string button1Text = "Yes";
        public string button2Text = "No";
        public string button3Text = "Maybe";
        public int numberOfButtons;

        public MessageTemplate(string _header, string _message, string _button1Text)
        {
            header = _header;
            message = _message;
            button1Text = _button1Text;
            numberOfButtons = 1;
        }

        public MessageTemplate(string _header, string _message, string _button1Text, string _button2Text)
        {
            header = _header;
            message = _message;
            button1Text = _button1Text;
            button2Text = _button2Text;
            numberOfButtons = 2;
        }

        public MessageTemplate(string _header, string _message, string _button1Text, string _button2Text, string _button3Text)
        {
            header = _header;
            message = _message;
            button1Text = _button1Text;
            button2Text = _button2Text;
            button3Text = _button3Text;
            numberOfButtons = 3;
        }
    }

    [Serializable]
    public class MessageBoxEvent : UnityEvent<int> { } 
}